4Suite API Documentation: Ft.Xml.Xslt.NumberElement

4Suite™ API Documentation

# ► Module Ft.Xml.Xslt.NumberElement

Implementation of xsl:number

    Copyright 2003 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Classes: NameTest, NodeTypeTest, NumberElement |  |  |  | Globals: ANY, DEFAULT_FORMAT, DEFAULT_LANG, EMPTY_NAMESPACE, MULTIPLE, SIMPLE, SINGLE, XSL_NAMESPACE

## Classes

class NameTest

  ### Methods

  __init__(self, node)
  match(self, context, node)
class NodeTypeTest

  ### Methods

  __init__(self, node)
  match(self, context, node)
class NumberElement(Ft.Xml.Xslt.StylesheetTree.XsltElement)

  ### Methods

  createFormatter(self, format, language=None, letterValue=None)
    Creates a formatter appropriate for the given language and letterValue, or a default, English-based formatter. Raises an exception if the language or letterValue is unsupported. Currently, if the language value is given, it must indicate English.
  instantiate(self, context, processor)
    Overrides: instantiate from class XsltElement
  setup(self)
    Overrides: setup from class XsltElement

  ### Methods inherited from class Ft.Xml.Xslt.StylesheetTree.XsltElement

  __init__, __str__, appendChild, expandQName, insertChild, parseAVT, parseExpression, parsePattern, processChildren, splitQName

  ### Methods inherited from class Ft.Xml.Xslt.StylesheetTree.XsltNode

  idle, isLastChild, isPseudoNode, pprint, prime

  ### Members

  category = 0
  content = <Ft.Xml.Xslt.ContentInfo.Atom instance>
  doesSetup = 1
  legalAttrs = {'count': <Ft.Xml.Xslt.AttributeInfo.Pattern instance>, 'format': <Ft.Xml.Xslt.AttributeInfo.StringAvt instance>, 'from': <Ft.Xml.Xslt.AttributeInfo.Pattern instance>, 'grouping-separator': <Ft.Xml.Xslt.AttributeInfo.CharAvt instance>, 'grouping-size': <Ft.Xml.Xslt.AttributeInfo.NumberAvt instance>, 'lang': <Ft.Xml.Xslt.AttributeInfo.NMToken instance>, 'letter-value': <Ft.Xml.Xslt.AttributeInfo.ChoiceAvt instance>, 'level': <Ft.Xml.Xslt.AttributeInfo.Choice instance>, 'value': <Ft.Xml.Xslt.AttributeInfo.Expression instance>}

  ### Members inherited from class Ft.Xml.Xslt.StylesheetTree.XsltElement

  validator

  ### Members inherited from class Ft.Xml.Xslt.StylesheetTree.XsltNode

  attributes, baseUri, children, columnNumber, doesIdle, doesPrime, expandedName, importIndex, lineNumber, nodeName, parent, root

## Globals

ANY = 2
DEFAULT_FORMAT = '1'
DEFAULT_LANG = 'en'
EMPTY_NAMESPACE = None
MULTIPLE = 1
SIMPLE = 3
SINGLE = 0
XSL_NAMESPACE = u'http://www.w3.org/1999/XSL/Transform'